cadl.gif — CADL 1.0.0 documentation

# Source code for cadl.gif

    """Utility for creating a GIF.
    """
    """
    Copyright 2017 Parag K. Mital.  See also NOTICE.md.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
    """
    import numpy as np
    import matplotlib.pyplot as plt
    import matplotlib.animation as animation

    def build_gif(imgs, interval=0.1, dpi=72,
                  save_gif=True, saveto='animation.gif',
                  show_gif=False, cmap=None):
        """Take an array or list of images and create a GIF.

        Parameters
        ----------
        imgs : np.ndarray or list
            List of images to create a GIF of
        interval : float, optional
            Spacing in seconds between successive images.
        dpi : int, optional
            Dots per inch.
        save_gif : bool, optional
            Whether or not to save the GIF.
        saveto : str, optional
            Filename of GIF to save.
        show_gif : bool, optional
            Whether or not to render the GIF using plt.
        cmap : None, optional
            Optional colormap to apply to the images.

        Returns
        -------
        ani : matplotlib.animation.ArtistAnimation
            The artist animation from matplotlib.  Likely not useful.
        """
        imgs = np.asarray(imgs)
        h, w, *c = imgs[0].shape
        fig, ax = plt.subplots(figsize=(np.round(w / dpi), np.round(h / dpi)))
        fig.subplots_adjust(bottom=0)
        fig.subplots_adjust(top=1)
        fig.subplots_adjust(right=1)
        fig.subplots_adjust(left=0)
        ax.set_axis_off()

        if cmap is not None:
            axs = list(map(lambda x: [
                ax.imshow(x, cmap=cmap)], imgs))
        else:
            axs = list(map(lambda x: [
                ax.imshow(x)], imgs))

        ani = animation.ArtistAnimation(
            fig, axs, interval=interval * 1000, repeat_delay=0, blit=True)

        if save_gif:
            ani.save(saveto, writer='imagemagick', dpi=dpi)

        if show_gif:
            plt.show()
        else:
            plt.close(fig)
        return ani